@@ -22,9 +22,7 @@ This file is a document manager for the Solr search engine, but the intent
 is that this file can be used as an example to add on different backends.
 To extend this to other systems, simply implement the exact same class and
 replace the method definitions with API calls for the desired backend.
-Each method is detailed to describe the desired behavior.
 """
-#!/usr/env/python
 import sys
 import logging
 
@@ -44,13 +42,6 @@ class DocManager():
 
     def __init__(self, url, auto_commit=True, unique_key='_id'):
         """Verify Solr URL and establish a connection.
-
-        This method may vary from implementation to implementation, but it
-        should verify the url to the backend and return None if that fails.
-        It should also create the connection to the backend, and start a
-        periodic committer if necessary. The Solr uniqueKey is '_id' in
-        the sample schema, but this may be overridden by user defined
-        configuration.
         """
         if verify_url(url) is False:
             raise SystemError
@@ -83,11 +74,6 @@ class DocManager():
 
     def search(self, start_ts, end_ts):
         """Called to query Solr for documents in a time range.
-
-        This method is only used by rollbacks to query all the documents in
-        Solr within a certain timestamp window. The input will be two longs
-        (converted from Bson timestamp) which specify the time range. The
-        return value should be an iterable set of documents.
         """
         query = '_ts: [%s TO %s]' % (start_ts, end_ts)
         return self.solr.search(query, rows=100000000)
@@ -100,24 +86,11 @@ class DocManager():
 
     def commit(self):
         """This function is used to force a commit.
-
-        It is used only in the beginning of rollbacks and in test cases, and is
-        not meant to be called in other circumstances. The body should commit
-        all documents to the backend engine (like auto_commit), but not have
-        any timers or run itself again (unlike auto_commit). In the event of
-        too many Solr searchers, the commit is wrapped in a retry_until_ok to
-        keep trying until the commit goes through.
         """
         retry_until_ok(self.solr.commit)
 
     def run_auto_commit(self):
         """Periodically commits to the Solr server.
-
-        This function commits all changes to the Solr engine, and then starts a
-        timer that calls this function again in one second. The reason for this
-        function is to prevent overloading Solr from other searchers. This
-        function may be modified based on the backend engine and how commits
-        are handled, as timers may not be necessary in all instances.
         """
         self.solr.commit()
         if self.auto_commit:
@@ -125,11 +98,6 @@ class DocManager():
 
     def get_last_doc(self):
         """Returns the last document stored in the Solr engine.
-
-        This method is used for rollbacks to establish the rollback window,
-        which is the gap between the last document on a mongo shard and the
-        last document in Solr. If there are no documents, this functions
-        returns None. Otherwise, it returns the first document.
         """
         #search everything, sort by descending timestamp, return 1 row
         result = self.solr.search('*:*', sort='_ts desc', rows=1
